@@ -3,6 +3,7 @@ import mimetypes
 import urllib.request
 import uuid
 import zipfile
+from enum import Enum
 from typing import List
 
 import requests
@@ -66,48 +67,6 @@ class SDK:
         return response.json()
 
     def assign_task(self, task, userid=None, email=None):
-        """Assing task to specific user with either userid of email.
-
-                Args:
-                    task: id of a task.
-                    userid: Optional userid.
-                    email: Optional email.
-
-                Returns:
-                 {"task":
-                    {
-                        "sample": {
-                            "isSample": false,
-                            "updatedAt": "2021-10-14T08:20:31.259Z"
-                        },
-                        "review": {
-                            "status": "Todo"
-                        },
-                        "answer": {
-                            "tools": [],
-                            "classifications": [],
-                            "relations": []
-                        },
-                        "status": "TODO",
-                        "isBenchmark": false,
-                        "deleted": false,
-                        "issues": [],
-                        "openIssuesCount": 0,
-                        "isPreLabeled": true,
-                        "isFlag": false,
-                        "isStar": false,
-                        "_id": "6167e84f2a810d000e9d3186",
-                        "project": "6167dfee2a810d000e9d313f",
-                        "asset": {
-                            "_id": "6167e84f2a810d000e9d3185",
-                            "externalId": "text_file.txt",
-                            "data": "https://angohub-public-assets.s3.eu-central-1.amazonaws.com/uploaded-data-d187239d-9fc0-4565-983d-50c7b42b258b.txt"
-                        },
-                        "organization": "61435781cdb61b0013d05a03",
-                        "createdAt": "2021-10-14T08:20:31.259Z"
-                    }
-                }
-         """
         url = "%s/v2/task/assign" % self.host
 
         payload = {"task": task}
@@ -218,7 +177,7 @@ class SDK:
 
         for a in assets:
             if integration_id:
-                    a['storage'] = integration_id
+                a['storage'] = integration_id
             if "batches" in a:
                 a['tags'] = switch_tags_names_with_ids(a['batches'])
 
@@ -267,7 +226,6 @@ class SDK:
         if external_id is None and asset_id is None:
             return Exception("External id or Assest Id should be provided!")
 
-
         url = "%s/v2/priority/%s" % (self.host, project_id)
 
         payload = {
@@ -422,4 +380,18 @@ class SDK:
             "description": description,
         }
         response = requests.request("POST", url, headers=headers, json=payload)
-        return response.json()
\ No newline at end of file
+        return response.json()
+
+    def create_webhook(self, webhook_url: str, project_id: str, secret: str, types: List[str]):
+        url = "%s/v2/webhook" % self.host
+        headers = {
+            'apikey': self.api_key
+        }
+        payload = {
+            "url": webhook_url,
+            "types": types,
+            "secret": secret,
+            "project": project_id
+        }
+        response = requests.request("POST", url, headers=headers, json=payload)
+        return response.json()
